package com.ruoyi.ai.service.impl;

import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ai.mapper.AiUserMessageMapper;
import com.ruoyi.ai.domain.AiUserMessage;
import com.ruoyi.ai.service.IAiUserMessageService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 站内信管理Service业务层处理
 * 
 * @author shi
 * @date 2025-11-13
 */
@Service
public class AiUserMessageServiceImpl implements IAiUserMessageService {

    @Autowired
    private AiUserMessageMapper aiUserMessageMapper;

    /**
     * 查询站内信管理
     * 
     * @param id 站内信管理主键
     * @return 站内信管理
     */
    @Override
    public AiUserMessage selectAiUserMessageById(Long id) {
        return aiUserMessageMapper.selectAiUserMessageById(id);
    }

    /**
     * 查询站内信管理列表
     * 
     * @param aiUserMessage 站内信管理
     * @return 站内信管理
     */
    @Override
    public List<AiUserMessage> selectAiUserMessageList(AiUserMessage aiUserMessage) {
        return aiUserMessageMapper.selectAiUserMessageList(aiUserMessage);
    }

    /**
     * 分页查询站内信管理列表
     *
     * @param aiUserMessage 站内信管理
     * @return 站内信管理
     */
    @Override
    public IPage<AiUserMessage> selectAiUserMessagePage(Page page, AiUserMessage aiUserMessage) {
        LambdaQueryWrapper<AiUserMessage> query = Wrappers.lambdaQuery(aiUserMessage);
        query.eq(AiUserMessage::getDelFlag, "0");
        return aiUserMessageMapper.selectPage(page, query);
    }

    /**
     * 新增站内信管理
     * 
     * @param aiUserMessage 站内信管理
     * @return 结果
     */
    @Override
    @Transactional
    public int insertAiUserMessage(AiUserMessage aiUserMessage) {
        aiUserMessage.setDelFlag("0");
        aiUserMessage.setCreateBy(SecurityUtils.getUsername());
        aiUserMessage.setCreateTime(DateUtils.getNowDate());
        int insert = aiUserMessageMapper.insert(aiUserMessage);
        if (aiUserMessage.getSendType() == 1 && aiUserMessage.getUserIds().size() > 0) {
            aiUserMessageMapper.addUserMessage(aiUserMessage.getId(), aiUserMessage.getUserIds());
        }
        return insert;
    }

    /**
     * 修改站内信管理
     * 
     * @param aiUserMessage 站内信管理
     * @return 结果
     */
    @Override
    @Transactional
    public int updateAiUserMessage(AiUserMessage aiUserMessage) {
        aiUserMessage.setUpdateBy(SecurityUtils.getUsername());
        aiUserMessage.setUpdateTime(DateUtils.getNowDate());
        // 删除原有的用户消息关系
        aiUserMessageMapper.deleteUserMessage(aiUserMessage.getId());
        if (aiUserMessage.getSendType() == 1 && aiUserMessage.getUserIds().size() > 0) {
            aiUserMessageMapper.addUserMessage(aiUserMessage.getId(), aiUserMessage.getUserIds());
        }
        return aiUserMessageMapper.updateById(aiUserMessage);
    }

    /**
     * 批量删除站内信管理
     * 
     * @param ids 需要删除的站内信管理主键
     * @return 结果
     */
    @Override
    public int deleteAiUserMessageByIds(Long[] ids)
    {
        return aiUserMessageMapper.deleteAiUserMessageByIds(ids);
    }

    /**
     * 删除站内信管理信息
     * 
     * @param id 站内信管理主键
     * @return 结果
     */
    @Override
    public int deleteAiUserMessageById(Long id)
    {
        return aiUserMessageMapper.deleteAiUserMessageById(id);
    }
}
